#!/bin/sh
#-------------------------------------------------------------------------------
# /opt/files/usr/local/bin/faxprint.sh - Druck von gzippten sff-Dateien
#
# Creation: 30.10.2002  Initialversion                                VER: 0.1
#           04.11.2002  Doku- und Kommentarnderungen
#                       Debugoptionen implementiert                   VER: 0.2
#           08.11.2002  Druckpositionierung implementiert             VER: 0.4
#           10.11.2002  absolute Pfade fr die .ps Dateien            VER: 0.5
#           30.05.2003  rem $1.prn im -t Abschnitt eingefgt          VER: 0.7
#           29.09.2004  Kompletter Neuaufbau fr fli4l Version 2.1.8  VER: 0.8
#           27.10.2004  Bugfix                                        VER: 0.81
#           19.07.2005  Anpassung fr fli4l Version 2.1.10/2.1.11     VER: 0.9
#           01.08.2005  Neue sff2misc-Version                         VER: 0.91
#           03.09.2005  Debugging mit FAXPRINT_DEBUG='yes', sff2misc  VER: 0.92
#           01.12.2005  Arbeitsverzeichnis /data (wenn vorhanden)     VER: 0.93
#-------------------------------------------------------------------------------
# falscher Aufruf
if [ "$1" = "" ] || [ "$1" = "-h" ]  || [ "$1" = "-?" ]
then
    echo "usage $0 [filename | -h ]"
    echo "      -h = help"
    exit 0
fi

# Variablen lesen
. /boot/rc.cfg

faxprint_logfile="/var/log/log.faxprint"
data_mount=`grep " /data " /proc/mounts | grep "rw"`
# Dateiname ohne Prfix und Suffix
filename=`basename "$1" | sed 's/\.gz$//; s/\.sff$//'`
filenamewithpath=`echo "$1" | sed 's/\.gz$//; s/\.sff$//'`

if [ -f /usr/bin/logger ]
then
    msgcmd="/usr/bin/logger -t faxprint -p local0"
    msgcmdfail="$msgcmd.error"
    msgcmdinfo="$msgcmd.info"
else
    msgcmd="echo"
    msgcmdfail="echo"
    msgcmdinfo="echo"
fi

do_msgcmdinfo ()
{
  if [ "$FAXPRINT_DEBUG" = "yes" ]
  then
      #echo "$message"
      echo "$message" >>"$faxprint_logfile"
      $msgcmdinfo "$message"
  fi
}

do_msgcmdfail ()
{
  if [ "$FAXPRINT_DEBUG" = "yes" ]
  then
      #echo "$message"
      echo "$message" >>"$faxprint_logfile"
      $msgcmdfail "$message"
  fi
}

faxprint_rmcommand ()
{
  rm -f "$faxprint_spooldir/$filename.sff"
  rm -f "$faxprint_spooldir/$filename.prn"
  rm -f "$faxprint_spooldir/$filename.ps"
}

if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    >"$faxprint_logfile"
fi

message="`date +%d.%m.%Y-%H:%M:%S:` starting faxprint.sh with file $1"
do_msgcmdinfo

path="/tmp"
message="`date +%d.%m.%Y-%H:%M:%S:` no mounted writeable partition /data found"

if [ -n "$data_mount" ]
then
    for i in minix ext2 ext3
    do
      if [ -n "`echo $data_mount | grep $i`" ]
      then
          path="/data"
          message="`date +%d.%m.%Y-%H:%M:%S:` mounted writeable partition /data with file system $i found"
      fi
    done
fi

do_msgcmdinfo

faxprint_spooldir="$path/faxprint_spooldir"
faxprint_pdfdir="$path/fax"
mkdir -p "$faxprint_spooldir"
mkdir -p "$faxprint_pdfdir"
message="`date +%d.%m.%Y-%H:%M:%S:` using spool dir $faxprint_spooldir and pdf dir $faxprint_pdfdir"
do_msgcmdinfo

message="`date +%d.%m.%Y-%H:%M:%S:` file without prefix and suffix is $filename"
do_msgcmdinfo

# entpacken
if [ -f $filenamewithpath.sff.gz ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` unpacking $filenamewithpath.sff.gz to $faxprint_spooldir/$filename.sff"
    do_msgcmdinfo
    cat "$filenamewithpath".sff.gz | gzip -d >"$faxprint_spooldir/$filename.sff"
    retval=$?

    if [ "$retval" = 0 ]
    then
        message="`date +%d.%m.%Y-%H:%M:%S:` $filenamewithpath.sff.gz successfull unpacked to $faxprint_spooldir/$filename.sff"
        do_msgcmdinfo
    else
        message="`date +%d.%m.%Y-%H:%M:%S:` cannot unpack $filenamewithpath.sff.gz to $faxprint_spooldir/$filename.sff"
        do_msgcmdfail
        faxprint_rmcommand
        exit 1
    fi
else
    message="`date +%d.%m.%Y-%H:%M:%S:` copying $filenamewithpath.sff to $faxprint_spooldir/$filename.sff"
    do_msgcmdinfo
    cp "$filenamewithpath".sff "$faxprint_spooldir/$filename.sff"
    retval=$?

    if [ "$retval" = 0 ]
    then
        message="`date +%d.%m.%Y-%H:%M:%S:` $filenamewithpath.sff successfull copied to $faxprint_spooldir/$filename.sff"
        do_msgcmdinfo
    else
        message="`date +%d.%m.%Y-%H:%M:%S:` cannot copy $filenamewithpath.sff to $faxprint_spooldir/$filename.sff"
        do_msgcmdfail
        faxprint_rmcommand
        exit 1
    fi
fi

# Umwandlung von sff zu Postscript
message="`date +%d.%m.%Y-%H:%M:%S:` converting $faxprint_spooldir/$filename.sff to $faxprint_spooldir/$filename.ps"
do_msgcmdinfo

/usr/local/bin/sff2misc -p "$faxprint_spooldir/$filename.sff" "$faxprint_spooldir/$filename"
retval=$?

if [ "$retval" = 0 ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` $faxprint_spooldir/$filename.sff successfull converted to $faxprint_spooldir/$filename.ps"
    do_msgcmdinfo
else
    message="`date +%d.%m.%Y-%H:%M:%S:` cannot convert $faxprint_spooldir/$filename.sff to $faxprint_spooldir/$filename.ps"
    do_msgcmdfail
    faxprint_rmcommand
    exit 1
fi

# Umwandlung von Postscript zu PDF
if [ "$FAXPRINT_MAKE_PDF" = "yes" ]
then
    if [ "$FAXPRINT_DEBUG" = "yes" ]
    then
        message="`date +%d.%m.%Y-%H:%M:%S:` converting $faxprint_spooldir/$filename.ps to $path/fax/$filename.pdf"
        do_msgcmdinfo

        /usr/local/bin/gs -q -dBATCH -dNOPAUSE        \
        -sDEVICE=pdfwrite                             \
        -sOutputFile="$faxprint_pdfdir/$filename.pdf" \
        /opt/files/usr/local/bin/margins.ps           \
        "$faxprint_spooldir/$filename.ps"             \
        >>"$faxprint_logfile" 2>&1
        retval=$?
    else
        /usr/local/bin/gs -q -dBATCH -dNOPAUSE        \
        -sDEVICE=pdfwrite                             \
        -sOutputFile="$faxprint_pdfdir/$filename.pdf" \
        /opt/files/usr/local/bin/margins.ps           \
        "$faxprint_spooldir/$filename.ps"
        retval=$?
    fi

    if [ "$retval" = 0 ]
    then
        message="`date +%d.%m.%Y-%H:%M:%S:` $faxprint_spooldir/$filename.ps successfull converted to $faxprint_pdfdir/$filename.pdf"
        do_msgcmdinfo
    else
        message="`date +%d.%m.%Y-%H:%M:%S:` cannot convert $faxprint_spooldir/$filename.ps to $faxprint_pdfdir/$filename.pdf"
        do_msgcmdfail
        faxprint_rmcommand
        exit 1
    fi
fi

# Umwandlung in Druckersprache
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` converting $faxprint_spooldir/$filename.ps to $faxprint_spooldir/$filename.prn"
    do_msgcmdinfo

    /usr/local/bin/gs -q -dBATCH -dNOPAUSE          \
    -sDEVICE="$FAXPRINT_PRINTER_TYP"                \
    -sOutputFile="$faxprint_spooldir/$filename.prn" \
    /opt/files/usr/local/bin/margins.ps             \
    "$faxprint_spooldir/$filename.ps"               \
    >>"$faxprint_logfile" 2>&1
    retval=$?
else
    /usr/local/bin/gs -q -dBATCH -dNOPAUSE          \
    -sDEVICE="$FAXPRINT_PRINTER_TYP"                \
    -sOutputFile="$faxprint_spooldir/$filename.prn" \
    /opt/files/usr/local/bin/margins.ps             \
    "$faxprint_spooldir/$filename.ps"
    retval=$?
fi

if [ "$retval" = 0 ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` $faxprint_spooldir/$filename.ps successfull converted to $faxprint_spooldir/$filename.prn"
    do_msgcmdinfo
else
    message="`date +%d.%m.%Y-%H:%M:%S:` cannot convert $faxprint_spooldir/$filename.ps to $faxprint_spooldir/$filename.prn"
    do_msgcmdfail
    faxprint_rmcommand
    exit 1
fi

# Drucken
if [ "$FAXPRINT_DEBUG" = "yes" ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` printing $faxprint_spooldir/$filename.prn on $FAXPRINT_PRINTER_QUEUE"
    do_msgcmdinfo

    /usr/bin/lpr -P"$FAXPRINT_PRINTER_QUEUE" "$faxprint_spooldir/$filename.prn" >>"$faxprint_logfile" 2>&1
    retval=$?
else
    /usr/bin/lpr -P"$FAXPRINT_PRINTER_QUEUE" "$faxprint_spooldir/$filename.prn"
    retval=$?
fi

if [ "$retval" = 0 ]
then
    message="`date +%d.%m.%Y-%H:%M:%S:` $faxprint_spooldir/$filename.prn successfull printed on $FAXPRINT_PRINTER_QUEUE"
    do_msgcmdinfo
else
    message="`date +%d.%m.%Y-%H:%M:%S:` cannot print $faxprint_spooldir/$filename.prn on $FAXPRINT_PRINTER_QUEUE"
    do_msgcmdfail
    faxprint_rmcommand
    exit 1
fi

# Muell aufraeumen
faxprint_rmcommand

message="`date +%d.%m.%Y-%H:%M:%S:` ending faxprint.sh with file $1"
do_msgcmdinfo

exit 0
